<div align="center">
    <img src="./gti/gti.png"/>
</div>
<div align="center">

# Golf GTI
A simple script that shows a Golf GTI when you accidentally type gti instead of git. 

[![PyPI - License](https://img.shields.io/pypi/l/GolfGTI)](https://pypi.org/project/GolfGTI/ "View on pypi")
[![PyPI](https://img.shields.io/pypi/v/GolfGTI)](https://pypi.org/project/GolfGTI/ "View on pypi")
[![Downloads](https://static.pepy.tech/badge/golfgti)](https://pepy.tech/project/golfgti)
</div>

Tired of seeing the boring  
```diff
-gti: The term 'gti' is not recognized as a name of a cmdlet, function, script file, or executable program. Check the spelling of the name, or if a path was included, verify that the path is correct and try again.
```
then this package is for you! Every time you misspell git you'll be greeted with a small Golf GTI on your screen.

## Install GolfGTI
GolfGTI is tested on Windows 10 & 11 with python > 3.1.
To install GolfGTI you simple run
```
pip install GolfGTI
```
A global command `gti` will be created for you to use in terminal.
